@@ -411,15 +411,15 @@ class OPCUATestCase(unittest.TestCase):
     def test_get_self_service_token_expired(self):
         auth_client = AUTH_CLIENT(rest_url=URL, username=username, password=password)
         auth_client.token = Token(access_token=auth_session_id, expires_at=auth_expires_at_2hrs_ago)
-        auth_client.token.expires_at = datetime.datetime.now() - datetime.timedelta(hours=2)
+        auth_client.token.expires_at = datetime.datetime.utcnow() - datetime.timedelta(hours=2)
         token_expired = auth_client.check_if_token_has_expired()
         assert token_expired == True
 
     def test_get_self_service_token_expired_none(self):
         auth_client = AUTH_CLIENT(rest_url=URL, username=username, password=password)
-        auth_client.token = Token(access_token=auth_session_id, expires_at=None)
+        auth_client.token = Token(access_token=auth_session_id)
         token_expired = auth_client.check_if_token_has_expired()
-        assert token_expired == False
+        assert token_expired == True
 
 if __name__ == "__main__":
     unittest.main()
